# Diator - CQRS Library for Python (ON DEVELOPMENT STAGE!!!)

Diator is a Python library for implementing CQRS pattern in your Python applications. It provides a set of abstractions and utilities to help you separate your read and write concerns, allowing for better scalability, performance, and maintainability of your application.

## Features

- Implements the CQRS pattern
- Simple, yet flexible API
- Supports multiple storage backends
- Easy to integrate with existing codebases
- Well-documented

## Installation

You can install Diator using pip:

```bash
pip install diator
```
